@@ -7,6 +7,6 @@ if TYPE_CHECKING:
 
 
 def update(new: "DataIndex", old: "BaseDataIndex") -> None:
-    for change in diff(old, new, meta_only=True):
+    for change in diff(old, new, with_unchanged=True, meta_only=True):
         if change.typ == UNCHANGED:
             change.new.hash_info = change.old.hash_info
